@@ -44,7 +44,7 @@ if __name__ == "__main__":
     endpoint = Endpoint("abalone-regression-end")
 
     # Get a DataFrame of data (not used to train) and run predictions
-    athena_table = fs.get_training_view_table()
+    athena_table = fs.view("training").table
     df = fs.query(f"SELECT * FROM {athena_table} where training = 0")
     results = endpoint.inference(df)
     print(results[["class_number_of_rings", "prediction"]])
