@@ -68,7 +68,7 @@ def column_stats(data_source: DataSourceAbstract, recompute: bool = False) -> di
     #
 
     # Get the column names and types from the DataSource
-    column_details = data_source.column_details(view="computation")
+    column_details = data_source.view("computation").column_details()
     column_data = {name: {"dtype": dtype} for name, dtype in column_details.items()}
     data_source.log.info(f"Computing Column Statistics for {list(column_data.keys())} columns...")
 
@@ -93,13 +93,13 @@ def column_stats(data_source: DataSourceAbstract, recompute: bool = False) -> di
 
     # Figure out which columns are numeric
     num_type = ["double", "float", "int", "bigint", "smallint", "tinyint"]
-    details = data_source.column_details(view="computation")
+    details = data_source.view("computation").column_details()
     numeric = [column for column, data_type in details.items() if data_type in num_type]
     non_numeric = [column for column, data_type in details.items() if data_type not in num_type]
     all_columns = numeric + non_numeric
 
-    # Grab the  DataSource table name
-    table = data_source.get_table_name()
+    # Grab the DataSource computation table name
+    table = data_source.view("computation").table
 
     # Now call the queries to compute the counts of distinct, nulls, and zeros
     data_source.log.info("Computing Unique values...")
@@ -140,10 +140,6 @@ if __name__ == "__main__":
     # What's my SageWorks UUID
     print(f"UUID: {my_data.uuid}")
 
-    # Set computation view columns
-    # computation_cols = my_data.columns
-    # my_data.set_computation_columns(computation_cols)
-
     # Get column stats for computation columns
     my_column_stats = column_stats(my_data)
     print("\nColumn Stats:")
