@@ -41,9 +41,10 @@ class Outliers:
         # Compute the numeric outliers
         outlier_df = self._numeric_outliers(data_source, scale, use_stddev)
 
-        # If there are no outliers, return a DataFrame with defined columns but no rows
+        # If there are no outliers, return a DataFrame with the computation columns but no rows
         if outlier_df is None:
-            return pd.DataFrame(columns=data_source.columns + ["outlier_group"])
+            columns = data_source.view("computation").columns
+            return pd.DataFrame(columns=columns + ["outlier_group"])
 
         # Get the top N outliers for each outlier group
         outlier_df = self.get_top_n_outliers(outlier_df)
@@ -82,7 +83,7 @@ class Outliers:
             return None
 
         # Get the column names and types from the DataSource
-        column_details = data_source.column_details(view="computation")
+        column_details = data_source.view("computation").column_details()
 
         # For every column in the data_source that is numeric get the outliers
         # This loop computes the columns, lower bounds, and upper bounds for the SQL query
@@ -142,11 +143,11 @@ class Outliers:
         Returns:
             str: A SQL query to compute outliers for multiple columns
         """
-        # Grab the  DataSource table name
-        table = data_source.get_table_name()
+        # Grab the DataSource computation table name
+        table = data_source.view("computation").table
 
         # Get the column names and types from the DataSource
-        column_details = data_source.column_details(view="computation")
+        column_details = data_source.view("computation").column_details()
         sql_columns = ", ".join([f'"{col}"' for col in column_details.keys()])
 
         query = f"SELECT {sql_columns} FROM {table} WHERE "
