@@ -21,13 +21,13 @@ def value_counts(data_source: DataSourceAbstract) -> dict[dict]:
               'col2': ...}
     """
 
-    # Grab the  DataSource table name
-    table = data_source.get_table_name()
+    # Grab the DataSource computation table name
+    table = data_source.view("computation").table
 
     # For every column in the table that is string, compute the value_counts
     data_source.log.info("Computing value_counts for all string columns...")
     value_count_dict = dict()
-    column_details = data_source.column_details(view="computation")
+    column_details = data_source.view("computation").column_details()
     for column, data_type in column_details.items():
         if data_type in ["string", "boolean"]:
             # Combined query to get both top and bottom counts
