@@ -180,6 +180,8 @@ class Meta:
         Returns:
             dict: Detailed information about all the Data Sources in AWS
         """
+        if refresh:
+            self.log.monitor("DataSources Deep Dive Force Refresh...")
         data = self.aws_broker.get_metadata(ServiceCategory.DATA_CATALOG, force_refresh=refresh)
 
         # Data Sources are in two databases, 'sageworks' and 'sagemaker_featurestore'
@@ -221,7 +223,7 @@ class Meta:
             refresh (bool, optional): Force a refresh of the metadata. Defaults to False.
 
         Returns:
-            dict: Detailed information about the data source (or None if not found)
+            dict: Detailed information about the view (or None if not found)
         """
         data = self.views_deep(database=database, refresh=refresh)
         return data.get(view_name)
@@ -236,6 +238,8 @@ class Meta:
         Returns:
             dict:  Detailed information about all the Views in AWS
         """
+        if refresh:
+            self.log.monitor("Views Deep Dive Force Refresh...")
         data = self.aws_broker.get_metadata(ServiceCategory.DATA_CATALOG, force_refresh=refresh)
 
         # Views are in two databases, 'sageworks' and 'sagemaker_featurestore'
@@ -297,6 +301,8 @@ class Meta:
         Returns:
             dict: A summary of the Feature Sets in AWS
         """
+        if refresh:
+            self.log.monitor("FeatureSets Deep Dive Force Refresh...")
         return self.aws_broker.get_metadata(ServiceCategory.FEATURE_STORE, force_refresh=refresh)
 
     def models(self, refresh: bool = False) -> pd.DataFrame:
@@ -312,9 +318,12 @@ class Meta:
         model_summary = []
         for model_group_name, model_list in model_data.items():
 
-            # Sanity check
+            # Sanity check for empty Model Package Groups
             if not model_list:
-                self.log.critical(f"No models found for {model_group_name}")
+                self.log.error(f"No models found in {model_group_name}")
+                summary = {"Model Group": model_group_name, "Health": "failed", "Owner": "empty", "Model Type": "empty"}
+                summary.update({key: "-" for key in ["Created", "Ver", "Tags", "Input", "Status", "Description"]})
+                model_summary.append(summary)
                 continue
 
             # Get Summary information for the 'latest' model in the model_list
@@ -362,6 +371,8 @@ class Meta:
         Returns:
             dict: A summary of the Models in AWS
         """
+        if refresh:
+            self.log.monitor("Models Deep Dive Force Refresh...")
         return self.aws_broker.get_metadata(ServiceCategory.MODELS, force_refresh=refresh)
 
     def endpoints(self, refresh: bool = False) -> pd.DataFrame:
@@ -410,6 +421,8 @@ class Meta:
         Returns:
             dict: A summary of the Endpoints in AWS
         """
+        if refresh:
+            self.log.monitor("Endpoints Deep Dive Force Refresh...")
         return self.aws_broker.get_metadata(ServiceCategory.ENDPOINTS, force_refresh=refresh)
 
     def pipelines(self, refresh: bool = False) -> pd.DataFrame:
