@@ -28,7 +28,6 @@ class DataSourceAbstract(Artifact):
         # Set up our instance attributes
         self._database = database
         self._table_name = data_uuid
-        self._display_view = None
 
     def __post_init__(self):
         # Call superclass post_init
@@ -38,7 +37,8 @@ class DataSourceAbstract(Artifact):
         """Get the database for this Data Source"""
         return self._database
 
-    def get_table_name(self) -> str:
+    @property
+    def table(self) -> str:
         """Get the base table name for this Data Source"""
         return self._table_name
 
@@ -58,28 +58,19 @@ class DataSourceAbstract(Artifact):
         """Return the column names for this Data Source"""
         pass
 
+    @property
     @abstractmethod
     def column_types(self) -> list[str]:
         """Return the column types for this Data Source"""
         pass
 
-    def column_details(self, view: str = "all") -> dict:
+    def column_details(self) -> dict:
         """Return the column details for this Data Source
-        Args:
-            view (str): The view to get column details for (default: "all")
+
         Returns:
             dict: The column details for this Data Source
         """
-        names = self.columns
-        types = self.column_types()
-        if view == "display":
-            return {name: type_ for name, type_ in zip(names, types) if name in self.get_display_columns()}
-        elif view == "computation":
-            return {name: type_ for name, type_ in zip(names, types) if name in self.get_computation_columns()}
-        elif view == "all":
-            return {name: type_ for name, type_ in zip(names, types)}  # Return the full column details
-        else:
-            raise ValueError(f"Unknown column details view: {view}")
+        return dict(zip(self.columns, self.column_types))
 
     def views(self) -> list[str]:
         """Return the views for this Data Source"""
@@ -98,46 +89,45 @@ class DataSourceAbstract(Artifact):
 
         return View(self, view_name)
 
-    def get_display_columns(self) -> list[str]:
-        """Get the columns from our display view
-        Returns:
-            list[str]: The columns from our display view
-        """
-        return self.view("display").columns
-
-    def set_display_columns(self, display_columns: list[str], onboard: bool = True):
+    def set_display_columns(self, diplay_columns: list[str]):
         """Set the display columns for this Data Source
 
         Args:
-            display_columns (list[str]): The display columns for this Data Source
-            onboard (bool): Onboard the Data Source after setting the display columns (default: True)
+            diplay_columns (list[str]): The display columns for this Data Source
         """
-        self.log.important(f"Setting Display Columns...{display_columns}")
+        # Check mismatch of display columns to computation columns
+        c_view = self.view("computation")
+        computation_columns = c_view.columns
+        mismatch_columns = [col for col in diplay_columns if col not in computation_columns]
+        if mismatch_columns:
+            self.log.monitor(f"Display View/Computation mismatch: {mismatch_columns}")
+
+        self.log.important(f"Setting Display Columns...{diplay_columns}")
         from sageworks.core.views import DisplayView
 
         # Create a NEW display view
-        DisplayView(self).create(column_list=display_columns)
-        if onboard:
-            self.onboard()
+        DisplayView.create(self, source_table=c_view.table, column_list=diplay_columns)
+
+    def set_computation_columns(self, computation_columns: list[str], recompute_stats: bool = True):
+        """Set the computation columns for this Data Source
+
+        Args:
+            computation_columns (list[str]): The computation columns for this Data Source
+            recompute_stats (bool): Recomputes all the stats for this Data Source (default: True)
+        """
+        self.log.important(f"Setting Computation Columns...{computation_columns}")
+        from sageworks.core.views import ComputationView
+
+        # Create a NEW computation view
+        ComputationView.create(self, column_list=computation_columns)
+        if recompute_stats:
+            self.recompute_stats()
 
     def _create_display_view(self):
         """Internal: Create the Display View for this DataSource"""
         from sageworks.core.views import View
 
-        self._display_view = View(self, "display")
-
-    def num_display_columns(self) -> int:
-        """Return the number of columns for the display view"""
-        return len(self.get_display_columns())
-
-    def get_computation_columns(self) -> list[str]:
-        return self.get_display_columns()
-
-    def set_computation_columns(self, computation_columns: list[str]):
-        self.set_display_columns(computation_columns)
-
-    def num_computation_columns(self) -> int:
-        return self.num_display_columns()
+        View(self, "display")
 
     @abstractmethod
     def query(self, query: str) -> pd.DataFrame:
@@ -149,9 +139,9 @@ class DataSourceAbstract(Artifact):
 
     @abstractmethod
     def execute_statement(self, query: str):
-        """Execute a non-returning SQL statement
+        """Execute an SQL statement that doesn't return a result
         Args:
-            query(str): The SQL query to execute
+            query(str): The SQL statement to execute
         """
         pass
 
@@ -269,7 +259,6 @@ class DataSourceAbstract(Artifact):
         details = self.summary()
         details["num_rows"] = self.num_rows()
         details["num_columns"] = self.num_columns()
-        details["num_display_columns"] = self.num_display_columns()
         details["column_details"] = self.column_details()
         return details
 
@@ -322,14 +311,11 @@ class DataSourceAbstract(Artifact):
         self.set_status("onboarding")
         self.remove_health_tag("needs_onboard")
 
-        # Make sure our views actually exist
+        # Make sure our display view actually exists
         self.view("display").ensure_exists()
 
-        # Compute the sample, column stats, and outliers
-        self.sample(recompute=True)
-        self.column_stats(recompute=True)
-        self.refresh_meta()  # Refresh the meta since outliers needs descriptive_stats and value_counts
-        self.outliers(recompute=True)
+        # Recompute the stats
+        self.recompute_stats()
 
         # Run a health check and refresh the meta
         time.sleep(2)  # Give the AWS Metadata a chance to update
@@ -338,3 +324,22 @@ class DataSourceAbstract(Artifact):
         self.details(recompute=True)
         self.set_status("ready")
         return True
+
+    def recompute_stats(self) -> bool:
+        """This is a BLOCKING method that will recompute the stats for the data source
+
+        Returns:
+            bool: True if the DataSource stats were recomputed successfully
+        """
+        self.log.important(f"Recomputing Stats {self.uuid}...")
+
+        # Make sure our computation view actually exists
+        self.view("computation").ensure_exists()
+
+        # Compute the sample, column stats, outliers, and smart_sample
+        self.sample(recompute=True)
+        self.column_stats(recompute=True)
+        self.refresh_meta()  # Refresh the meta since outliers needs descriptive_stats and value_counts
+        self.outliers(recompute=True)
+        self.smart_sample(recompute=True)
+        return True
