@@ -2,7 +2,6 @@
 
 import time
 from datetime import datetime, timezone
-from typing import Union
 
 import botocore.exceptions
 import pandas as pd
@@ -73,10 +72,6 @@ class FeatureSetCore(Artifact):
         # Spin up our Feature Store
         self.feature_store = FeatureStore(self.sm_session)
 
-        # Initialize our Views
-        self._display_view = None
-        self._training_view = None
-
         # Call superclass post_init
         super().__post_init__()
 
@@ -132,16 +127,14 @@ class FeatureSetCore(Artifact):
         """Return the column names of the Feature Set"""
         return list(self.column_details().keys())
 
+    @property
     def column_types(self) -> list[str]:
         """Return the column types of the Feature Set"""
         return list(self.column_details().values())
 
-    def column_details(self, view: str = "all") -> dict:
+    def column_details(self) -> dict:
         """Return the column details of the Feature Set
 
-        Args:
-            view (str): The view to get column details for (default: "all")
-
         Returns:
             dict: The column details of the Feature Set
 
@@ -150,7 +143,7 @@ class FeatureSetCore(Artifact):
             types, so we need to overlay that type information on top of the DataSource type information
         """
         fs_details = {item["FeatureName"]: item["FeatureType"] for item in self.feature_meta["FeatureDefinitions"]}
-        ds_details = self.data_source.column_details(view)
+        ds_details = self.data_source.column_details()
 
         # Overlay the FeatureSet type information on top of the DataSource type information
         for col, dtype in ds_details.items():
@@ -174,27 +167,42 @@ class FeatureSetCore(Artifact):
 
         return View(self, view_name)
 
-    def get_display_columns(self) -> list[str]:
-        """Get the columns from our display view
-        Returns:
-            list[str]: The columns from our display view
-        """
-        return self.view("display").columns
-
-    def set_display_columns(self, display_columns: list[str], onboard: bool = True):
+    def set_display_columns(self, diplay_columns: list[str]):
         """Set the display columns for this Data Source
 
         Args:
-            display_columns (list[str]): The display columns for this Data Source
-            onboard (bool): Onboard the Data Source after setting the display columns (default: True)
+            diplay_columns (list[str]): The display columns for this Data Source
         """
-        self.log.important(f"Setting Display Columns...{display_columns}")
+        # Check mismatch of display columns to computation columns
+        c_view = self.view("computation")
+        computation_columns = c_view.columns
+        mismatch_columns = [col for col in diplay_columns if col not in computation_columns]
+        if mismatch_columns:
+            self.log.monitor(f"Display View/Computation mismatch: {mismatch_columns}")
+
+        self.log.important(f"Setting Display Columns...{diplay_columns}")
         from sageworks.core.views import DisplayView
 
         # Create a NEW display view
-        DisplayView(self).create(column_list=display_columns)
-        if onboard:
-            self.onboard()
+        DisplayView.create(self, source_table=c_view.table, column_list=diplay_columns)
+
+    def set_computation_columns(self, computation_columns: list[str], reset_display: bool = True):
+        """Set the computation columns for this FeatureSet
+
+        Args:
+            computation_columns (list[str]): The computation columns for this FeatureSet
+            reset_display (bool): Also reset the display columns to match (default: True)
+        """
+        self.log.important(f"Setting Computation Columns...{computation_columns}")
+        from sageworks.core.views import ComputationView
+
+        # Create a NEW computation view
+        ComputationView.create(self, column_list=computation_columns)
+        self.recompute_stats()
+
+        # Reset the display columns to match the computation columns
+        if reset_display:
+            self.set_display_columns(computation_columns)
 
     def num_columns(self) -> int:
         """Return the number of columns of the Feature Set"""
@@ -255,8 +263,8 @@ class FeatureSetCore(Artifact):
         s3_output_path = self.feature_sets_s3_path + f"/{self.uuid}/datasets/all_{date_time}"
 
         # Make the query
-        view_table_name = self.view("training").view_table_name
-        query = f"SELECT * FROM {view_table_name}"
+        table = self.view("training").table
+        query = f"SELECT * FROM {table}"
         athena_query = FeatureGroup(name=self.uuid, sagemaker_session=self.sm_session).athena_query()
         athena_query.run(query, output_location=s3_output_path)
         athena_query.wait()
@@ -378,15 +386,6 @@ class FeatureSetCore(Artifact):
         # Force a refresh of the AWS Metadata (to make sure references to deleted artifacts are gone)
         self.aws_broker.get_metadata(ServiceCategory.FEATURE_STORE, force_refresh=True)
 
-    def list_views(self) -> list[str]:
-        """List all the views associated with this FeatureSet"""
-        from sageworks.core.views.view_utils import list_view_tables
-
-        view_tables = list_view_tables(self.data_source)
-        data_table_name = self.data_source.get_table_name()
-        # Each view will have the format: {data_table_name}_{view_name}
-        return [view_table.replace(data_table_name + "_", "") for view_table in view_tables]
-
     def ensure_feature_group_deleted(self, feature_group):
         status = "Deleting"
         while status == "Deleting":
@@ -412,30 +411,12 @@ class FeatureSetCore(Artifact):
         from sageworks.core.views import TrainingView
 
         # Create a NEW training view
-        TrainingView(self.data_source).create(id_column=id_column, holdout_ids=holdout_ids)
-
-    def get_training_view_table(self) -> Union[str, None]:
-        """Get the name of the training view for this FeatureSet
-
-        Returns:
-            str: The name of the training view for this FeatureSet
-        """
-        # Get the training view table name
-        return self.view("training").view_table_name
+        TrainingView.create(self, id_column=id_column, holdout_ids=holdout_ids)
 
     def delete_views(self):
         """Delete any views associated with this FeatureSet"""
         from sageworks.core.views.view_utils import delete_views_and_supplemental_data
 
-        # Delete the views
-        if self._display_view:
-            self._display_view.delete()
-            self._display_view = None
-        if self._training_view:
-            self._training_view.delete()
-            self._training_view = None
-
-        # Now delete any other views or supplemental data tables
         delete_views_and_supplemental_data(self.data_source)
 
     def descriptive_stats(self, recompute: bool = False) -> dict:
@@ -575,6 +556,15 @@ class FeatureSetCore(Artifact):
         self.set_status("ready")
         return True
 
+    def recompute_stats(self) -> bool:
+        """This is a BLOCKING method that will recompute the stats for the FeatureSet"""
+
+        # Call our underlying DataSource recompute stats method
+        self.log.important(f"Recomputing Stats {self.uuid}...")
+        self.data_source.recompute_stats()
+        self.details(recompute=True)
+        return True
+
 
 if __name__ == "__main__":
     """Exercise for FeatureSet Class"""
@@ -586,6 +576,10 @@ if __name__ == "__main__":
     pd.set_option("display.max_columns", 15)
     pd.set_option("display.width", 1000)
 
+    # Test new recompute_stats method (we're grabbing a datasource from the FeatureSet)
+    fs = LocalFeatureSetCore("abalone_features")
+    fs.recompute_stats()
+
     # Grab a FeatureSet object and pull some information from it
     my_features = LocalFeatureSetCore("test_features")
 
@@ -638,7 +632,7 @@ if __name__ == "__main__":
 
     # Set the holdout ids for the training view
     print("Setting hold out ids...")
-    table = my_features.get_training_view_table()
+    table = my_features.view("training").table
     df = my_features.query(f"SELECT id, name FROM {table}")
     my_holdout_ids = [id for id in df["id"] if id < 20]
     my_features.set_training_holdouts("id", my_holdout_ids)
