@@ -1,6 +1,7 @@
 """View: Read from a view (training, display, etc) for DataSources and FeatureSets."""
 
 import logging
+import time
 from typing import Union
 import pandas as pd
 import awswrangler as wr
@@ -9,7 +10,7 @@ import awswrangler as wr
 from sageworks.api import DataSource, FeatureSet
 from sageworks.core.artifacts.feature_set_core import FeatureSetCore
 from sageworks.api import Meta
-from sageworks.core.views.view_utils import list_supplemental_data_tables, delete_table
+from sageworks.core.views.view_utils import list_supplemental_data_tables, delete_table, view_details
 
 
 class View:
@@ -19,6 +20,21 @@ class View:
         ```
         view = View(DataSource/FeatureSet, "training")
         training_df = view.pull_dataframe()
+
+        # You can also pull from the DS/FS directly
+        display_view = ds.view("display")
+        print(display_view.columns)
+
+        # Get a DataFrame for the computation view
+        comp_view = fs.view("computation")
+        comp_df = comp_view.pull_dataframe()
+
+        # Query the view with a custom SQL query
+        query = f"SELECT * FROM {comp_view.table} WHERE age > 30"
+        df = comp_view.query(query)
+
+        # Delete the view
+        comp_view.delete()
         ```
     """
 
@@ -42,20 +58,31 @@ class View:
         self.auto_id_column = artifact.record_id if self.is_feature_set else None
 
         # Get the data_source from the artifact
+        self.artifact_name = artifact.uuid
         self.data_source = artifact.data_source if self.is_feature_set else artifact
         self.database = self.data_source.get_database()
 
-        # Set our view table name
-        self.base_table = self.data_source.get_table_name()
-        self.view_table_name = self.table_name()
+        # Construct our base_table_name
+        self.base_table_name = self.data_source.table
 
-        # Check if they turned off auto-creation
-        self.auto_create = kwargs.get("auto_create", True)
-        if self.auto_create and not self.exists():
-            if self.view_name in ["training", "display", "computation"]:
-                self._auto_create_view()
+        # Check if the view should be auto created
+        self.auto_created = False
+        if kwargs.get("auto_create_view", True) and not self.exists():
+
+            # Auto-create the view
+            if self._auto_create_view():
+                self.auto_created = True
             else:
-                self.log.error(f"View {self.view_name} for {self.data_source.uuid} does not exist...")
+                self.log.error(
+                    f"View {self.view_name} for {self.artifact_name} doesn't exist and cannot be auto-created..."
+                )
+                self.view_name = self.columns = self.column_types = self.source_table = self.base_table_name = None
+                return
+
+        # Now fill some details about the view
+        self.columns, self.column_types, self.source_table, self.join_view = view_details(
+            self.data_source.get_database(), self.table, self.data_source.boto3_session
+        )
 
     def pull_dataframe(self, limit: int = 50000, head: bool = False) -> Union[pd.DataFrame, None]:
         """Pull a DataFrame based on the view type
@@ -71,36 +98,41 @@ class View:
         # Pull the DataFrame
         if head:
             limit = 5
-        pull_query = f"SELECT * FROM {self.view_table_name} LIMIT {limit}"
+        pull_query = f"SELECT * FROM {self.table} LIMIT {limit}"
         df = self.data_source.query(pull_query)
         return df
 
+    def query(self, query: str) -> Union[pd.DataFrame, None]:
+        """Query the view with a custom SQL query
+
+        Args:
+            query (str): The SQL query to execute
+
+        Returns:
+            Union[pd.DataFrame, None]: The DataFrame for the query or None if it doesn't exist
+        """
+        return self.data_source.query(query)
+
+    def column_details(self) -> dict:
+        """Return a dictionary of the column names and types for this view
+
+        Returns:
+            dict: A dictionary of the column names and types
+        """
+        return dict(zip(self.columns, self.column_types))
+
     @property
-    def columns(self) -> list:
-        """Return the columns for the view"""
-
-        # Retrieve the table metadata
-        glue_client = self.data_source.boto3_session.client("glue")
-        response = glue_client.get_table(DatabaseName=self.database, Name=self.view_table_name)
-
-        # Extract the column names from the schema
-        column_names = [col["Name"] for col in response["Table"]["StorageDescriptor"]["Columns"]]
-
-        # Sanity check the column names
-        if not column_names:
-            raise ValueError(f"No columns found for view {self.view_table_name}")
-
-        return column_names
-
-    def table_name(self) -> str:
+    def table(self) -> str:
         """Construct the view table name for the given view type
 
         Returns:
             str: The view table name
         """
+        if self.view_name is None:
+            return None
         if self.view_name == "base":
-            return self.base_table
-        return f"{self.base_table}_{self.view_name}"
+            return self.base_table_name
+        return f"{self.base_table_name}_{self.view_name}"
 
     def delete(self):
         """Delete the database view (and supplemental data) if it exists."""
@@ -113,18 +145,22 @@ class View:
                 delete_table(self.data_source, table)
 
         # Now drop the view
-        self.log.important(f"Dropping View {self.view_table_name}...")
-        drop_view_query = f"DROP VIEW {self.view_table_name}"
+        self.log.important(f"Dropping View {self.table}...")
+        drop_view_query = f"DROP VIEW {self.table}"
 
         # Execute the DROP VIEW query
         try:
             self.data_source.execute_statement(drop_view_query, silence_errors=True)
         except wr.exceptions.QueryFailed as e:
             if "View not found" in str(e):
-                self.log.info(f"View {self.view_table_name} not found, this is fine...")
+                self.log.info(f"View {self.table} not found, this is fine...")
             else:
                 raise
 
+        # We want to do a small sleep so that AWS has time to catch up
+        self.log.info("Sleeping for 3 seconds after dropping view to allow AWS to catch up...")
+        time.sleep(3)
+
     def exists(self) -> bool:
         """Check if the view exists in the database
 
@@ -143,7 +179,7 @@ class View:
             return False
 
         # Check if the view exists
-        return self.view_table_name in views_df["Name"].values
+        return self.table in views_df["Name"].values
 
     def ensure_exists(self):
         """Ensure if the view exists by making a query directly to the database. If it doesn't exist, create it"""
@@ -156,55 +192,76 @@ class View:
         check_table_query = f"""
         SELECT table_name
         FROM information_schema.tables
-        WHERE table_schema = '{self.database}' AND table_name = '{self.view_table_name}'
+        WHERE table_schema = '{self.database}' AND table_name = '{self.table}'
         """
         _df = self.data_source.query(check_table_query)
         if _df.empty:
             self._auto_create_view()
 
-    def _auto_create_view(self):
-        """Internal: Automatically create a view training, display, and computation views"""
+    def _auto_create_view(self) -> bool:
+        """Internal: Automatically create a view training, display, and computation views
+
+        Returns:
+            bool: True if the view was created, False otherwise
+
+        Raises:
+            ValueError: If the view type is not supported
+        """
         from sageworks.core.views import DisplayView, ComputationView, TrainingView
 
         # First if we're going to auto-create, we need to make sure the data source exists
         if not self.data_source.exists():
             self.log.error(f"Data Source {self.data_source.uuid} does not exist...")
-            return
+            return False
 
-        # Auto create the standard views
+        # DisplayView
         if self.view_name == "display":
             self.log.important(f"Auto creating View {self.view_name} for {self.data_source.uuid}...")
-            self.auto_created = True
-            DisplayView(self.data_source).create()
-        elif self.view_name == "computation":
+            DisplayView.create(self.data_source)
+            return True
+
+        # ComputationView
+        if self.view_name == "computation":
             self.log.important(f"Auto creating View {self.view_name} for {self.data_source.uuid}...")
-            self.auto_created = True
-            ComputationView(self.data_source).create()
-        elif self.view_name == "training":
-            self.log.important(f"Auto creating View {self.view_name} for {self.data_source.uuid}...")
-            self.auto_created = True
-            TrainingView(self.data_source).create(id_column=self.auto_id_column)
-        else:
-            self.log.error(f"Auto-Create for {self.view_name} not implemented yet...")
+            ComputationView.create(self.data_source)
+            return True
+
+        # TrainingView
+        if self.view_name == "training":
+            # We're only going to create training views for FeatureSets
+            if self.is_feature_set:
+                self.log.important(f"Auto creating View {self.view_name} for {self.data_source.uuid}...")
+                TrainingView.create(self.data_source, id_column=self.auto_id_column)
+                return True
+            else:
+                self.log.warning("Training Views are only supported for FeatureSets...")
+                return False
+
+        # If we get here, we don't support auto-creating this view
+        self.log.warning(f"Auto-Create for {self.view_name} not implemented yet...")
+        return False
 
     def __repr__(self):
         """Return a string representation of this object"""
 
-        # FIXME: Revisit this later
-        auto = ""  # (Auto-Created)" if self.auto_created else ""
-        if self.is_feature_set:
-            return f'View: {self.database}:{self.view_table_name}{auto} for FeatureSet("{self.data_source.uuid}")'
-        else:
-            return f'View: {self.database}:{self.view_table_name}{auto} for DataSource("{self.data_source.uuid}")'
+        # Set up various details that we want to print out
+        auto = "(Auto-Created)" if self.auto_created else ""
+        artifact = "FeatureSet" if self.is_feature_set else "DataSource"
+
+        info = f'View: "{self.view_name}" for {artifact}("{self.artifact_name}")\n'
+        info += f"      Database: {self.database}\n"
+        info += f"      Table: {self.table}{auto}\n"
+        info += f"      Source Table: {self.source_table}\n"
+        info += f"      Join View: {self.join_view}"
+        return info
 
 
 if __name__ == "__main__":
     """Exercise the ViewManager Class"""
-
     # See tests/views/views_tests.py for more examples
-
-    # SageWorks Imports
+    import numpy as np
     from sageworks.api import DataSource, FeatureSet
+    from sageworks.core.views.pandas_to_view import PandasToView
 
     # Show trace calls
     logging.getLogger("sageworks").setLevel(logging.DEBUG)
@@ -236,9 +293,16 @@ if __name__ == "__main__":
     print(display_view.columns)
 
     # Delete the display view
-    # display_view.delete()
+    display_view.delete()
+
+    # Generate a DataFrame with the same id column and two random columns
+    my_df = fs.pull_dataframe()[["id", "height", "weight", "salary"]]
+    my_df["random1"] = np.random.rand(len(my_df))
+    my_df["random2"] = np.random.rand(len(my_df))
+
+    # Create a view with a PandasToView class
+    df_view = PandasToView("test_df", fs).create(df=my_df, id_column="id")
 
     # Test supplemental data tables deletion
-    fs = FeatureSet("abalone_features")
     view = View(fs, "test_df")
     view.delete()
