@@ -1,8 +1,13 @@
 """View Utils: A set of utilities for creating and managing views in SageWorks"""
 
+import base64
+import json
+import re
+from typing import Union
 import logging
 import pandas as pd
 import awswrangler as wr
+from botocore.exceptions import ClientError
 
 # SageWorks Imports
 from sageworks.api import DataSource
@@ -21,7 +26,7 @@ def get_column_list(data_source: DataSource, source_table: str = None) -> list[s
     Returns:
         list[str]: A list of column names
     """
-    source_table = source_table if source_table else data_source.get_table_name()
+    source_table = source_table if source_table else data_source.table
 
     # Query to get the column names
     column_query = f"""
@@ -42,12 +47,12 @@ def list_views(data_source: DataSource) -> list[str]:
     Returns:
         list[str]: A list containing only the last part of the view table names
     """
-    # Get the list of view tables from the original method
+    # Get the list of view tables for this data source
     view_tables = list_view_tables(data_source)
+    data_source_table = data_source.table
 
-    # Extract the last part of each table name
-    view_names = [table_name.split("_")[-1] for table_name in view_tables]
-    return view_names
+    # Each view will have the format: {data_table_name}_{view_name}
+    return [view_table.replace(data_source_table + "_", "") for view_table in view_tables]
 
 
 def list_view_tables(data_source: DataSource) -> list[str]:
@@ -59,15 +64,15 @@ def list_view_tables(data_source: DataSource) -> list[str]:
     Returns:
         list[str]: A list of view table names
     """
-    base_table_name = data_source.get_table_name()
+    base_table_name = data_source.table
 
-    # Use REGEXP_LIKE to match table names that start with base_table_name followed by one underscore
+    # Use LIKE to match table names that start with base_table_name followed by any characters
     view_query = f"""
     SELECT table_name
     FROM information_schema.tables
     WHERE table_schema = '{data_source.get_database()}'
       AND table_type = 'VIEW'
-      AND REGEXP_LIKE(table_name, '^{base_table_name}_[^_]+$')
+      AND table_name LIKE '{base_table_name}_%'
     """
     df = data_source.query(view_query)
     return df["table_name"].tolist()
@@ -82,7 +87,7 @@ def list_supplemental_data_tables(data_source: DataSource) -> list[str]:
     Returns:
         list[str]: A list of supplemental data table names
     """
-    base_table_name = data_source.get_table_name()
+    base_table_name = data_source.table
 
     # Use REGEXP_LIKE to match table names that start with an underscore, followed by the base_table_name,
     # followed by one underscore, and no more underscores
@@ -91,7 +96,7 @@ def list_supplemental_data_tables(data_source: DataSource) -> list[str]:
     FROM information_schema.tables
     WHERE table_schema = '{data_source.get_database()}'
       AND table_type = 'BASE TABLE'
-      AND REGEXP_LIKE(table_name, '^_{base_table_name}_[^_]+$')
+      AND table_name LIKE '{base_table_name}_%'
     """
     df = data_source.query(supplemental_data_query)
     return df["table_name"].tolist()
@@ -167,6 +172,101 @@ def delete_table(data_source: DataSource, table_name: str):
         log.info(f"Table {table_name} successfully deleted from database {database}.")
 
 
+def view_details(
+    database: str, table: str, boto3_session
+) -> (Union[list, None], Union[list, None], Union[str, None], bool):
+    """Pull the column names, types, and source table for the view
+
+    Args:
+        database (str): The database name
+        table (str): The view table
+        boto3_session: The boto3 session
+
+    Returns:
+        Union[list, None]: The column names (returns None if the table does not exist)
+        Union[list, None]: The column types (returns None if the table does not exist)
+        Union[str, None]: The source table the view was created from (returns None if not found)
+        bool: True if the view is a JOIN view, False otherwise
+    """
+
+    # Retrieve the table metadata
+    glue_client = boto3_session.client("glue")
+    try:
+        response = glue_client.get_table(DatabaseName=database, Name=table)
+
+        # Extract the column names and types from the schema
+        column_names = [col["Name"] for col in response["Table"]["StorageDescriptor"]["Columns"]]
+        column_types = [col["Type"] for col in response["Table"]["StorageDescriptor"]["Columns"]]
+
+        # Check if the table is a view and extract the source table from the SQL query
+        if response["Table"]["TableType"] != "VIRTUAL_VIEW":
+            return column_names, column_types, response["Table"]["Name"]
+        elif "ViewOriginalText" in response["Table"]:
+            view_sql_encoded = response["Table"]["ViewOriginalText"]
+            view_sql_decoded = _decode_view_sql(view_sql_encoded)
+            source_table = _extract_source_table(view_sql_decoded)
+            join_view = "JOIN" in view_sql_decoded
+            return column_names, column_types, source_table, join_view
+        else:
+            log.error(f"Failed to extract source table from view {table}.")
+            return column_names, column_types, None, False
+
+    # Handle the case where the table does not exist
+    except glue_client.exceptions.EntityNotFoundException:
+        log.warning(f"Table {table} not found in database {database}.")
+        return None, None, None, False
+    except ClientError as e:
+        log.error(f"An error occurred while retrieving table info: {e}")
+        return None, None, None, False
+
+
+def _decode_view_sql(encoded_sql: str) -> str:
+    """Decode the base64-encoded SQL query from the view.
+
+    Args:
+        encoded_sql (str): The encoded SQL query in the ViewOriginalText.
+
+    Returns:
+        str: The decoded SQL query.
+    """
+    # Extract the base64-encoded content from the comment
+    match = re.search(r"Presto View: ([\w=+/]+)", encoded_sql)
+    if match:
+        base64_sql = match.group(1)
+        decoded_bytes = base64.b64decode(base64_sql)
+        decoded_str = decoded_bytes.decode("utf-8")
+
+        # Parse the decoded string as JSON to extract the SQL
+        try:
+            view_json = json.loads(decoded_str)
+            return view_json.get("originalSql", "")
+        except json.JSONDecodeError:
+            log.error("Failed to parse the decoded view SQL as JSON.")
+            return ""
+    return ""
+
+
+def _extract_source_table(view_sql: str) -> Union[str, None]:
+    """Extract the source table from the SQL query of the view.
+
+    Args:
+        view_sql (str): The decoded SQL query used to create the view.
+
+    Returns:
+        Union[str, None]: The source table name if found, otherwise None.
+    """
+    # Use regex to find the source table in the SQL query
+    match = re.search(r"FROM\s+([^\s;]+)", view_sql, re.IGNORECASE)
+    table = match.group(1) if match else None
+
+    # Special case for join queries
+    if table.startswith("("):
+        table = table.replace("(", "")
+
+    # Return the source table name
+    return table
+
+
 if __name__ == "__main__":
     """Test the various view utilities"""
     from sageworks.api import FeatureSet
@@ -175,11 +275,19 @@ if __name__ == "__main__":
     fs = FeatureSet("abalone_features")
     my_data_source = fs.data_source
 
+    # Test view_details
+    print("View Details on the FeatureSet Table...")
+    print(view_details(my_data_source.get_database(), my_data_source.table, my_data_source.boto3_session))
+
+    print("View Details on the Training View...")
+    training_view = fs.view("training")
+    print(view_details(training_view.database, training_view.table, my_data_source.boto3_session))
+
     # Test get_column_list
     print(get_column_list(my_data_source))
 
     # Test get_column_list (with training view)
-    training_table = fs.view("training").view_table_name
+    training_table = fs.view("training").table
     print(get_column_list(my_data_source, training_table))
 
     # Test list_view_tables
